% Compute LP coeffs using the autocorrelation method
% s is the (finite-length) signal, p is the prediction order
% a are the computed LP coefficients, g is the gain (sqrt of residual variance)

function [a,g] = lp_coeffs(s,p)

R=xcorr (s,p) ; % autocorrelation sequence R(k) with k=-p,..,p
R(1:p)=[];      % delete the first p samples
if norm(R) ~= 0
  [a,v] = levinson(R,p);  % Levinson-Durbin recursion
                          % a=[1,-a1,-a2,...,-ap], v = variance of the residual
else
  a=[1, zeros(1,p)];
end
g=sqrt(sum(a'.*R)); % gain factor (= sqrt(v))
